@@ -131,7 +131,7 @@ test_that("error in busy handler", {
 
   dbExecute(con1, "BEGIN IMMEDIATE")
   expect_error(
-    expect_warning(
+    expect_message(
       dbExecute(con2, "BEGIN IMMEDIATE"),
       "Busy callback failed, aborting.*oops"
     ),
